Contribute - llvm-py
Description: Python bindings for LLVM
Keywords: llvm python compiler backend bindings

llvm-py
Python Bindings for LLVM

»Home »Examples »Download »User Guide »Contribute »License »About | # Contribute You can make a difference, just by: getting llvm-py to work on an as-yet-untested platform adding support for more LLVM features into llvm-py sending in patches for bugs you come across improving the test scripts and documentation spreading the word Useful links: Browse SVN: http://code.google.com/p/llvm-py/source/browse Issues tracker: http://code.google.com/p/llvm-py/issues/list Discussions: http://groups.google.com/group/llvm-py SVN HEAD can be checked out like so:
    $ svn co http://llvm-py.googlecode.com/svn/trunk/ llvm-py
Usual caveats apply: cutting edge, may be broken (but usually not), update and merge before sending patches etc.